=========
Tutorials
=========

These tutorials are step-by step guides for using Rubicon Java.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   tutorial-1
   tutorial-2


Tutorial 1 - Your first bridge
==============================

In :doc:`tutorial-1`, you will use Rubicon to invoke an existing Java
library on your computer.

Tutorial 2 - Writing your own class
===================================

In :doc:`tutorial-2`, you will write a Python class, and expose it to the
Java runtime.
